@@ -1,10 +1,10 @@
 """django-multimail
 
-.. moduleauthor:: Scott B. Bradley <scott@scott2b.com>
+.. moduleauthor:: Scott B. Bradley <scott@scott2b.com>, Twitter <@scott2b>
 """
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 __license__ = 'OSI Approved :: MIT License'
 
 __author__ = 'scott2b <Scott B. Bradley>'
 __email__ = 'scott@scott2b.com'
-__url__ = 'http://multimail.scott2b.com'
+__url__ = 'http://django-multimail.com'
